@@ -86,8 +86,8 @@
 /*
   Include declarations.
 */
-#include "magick.h"
-#include "defines.h"
+#include <magick/magick.h>
+#include <magick/defines.h>
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -419,6 +419,8 @@ int main(int argc,char **argv)
                     image_info.compression=BZipCompression;
                   if (Latin1Compare("Fax",option) == 0)
                     image_info.compression=FaxCompression;
+                  if (Latin1Compare("Group4",option) == 0)
+                    image_info.compression=Group4Compression;
                   if (Latin1Compare("JPEG",option) == 0)
                     image_info.compression=JPEGCompression;
                   if (Latin1Compare("LZW",option) == 0)
@@ -647,7 +649,7 @@ int main(int argc,char **argv)
         {
           if (strncmp("quality",option+1,2) == 0)
             {
-              image_info.quality=atoi(DefaultImageQuality);
+              image_info.quality=75;
               if (*option == '-')
                 {
                   i++;
