@@ -150,8 +150,8 @@
 /*
   Include declarations.
 */
-#include "magick.h"
-#include "defines.h"
+#include <magick/magick.h>
+#include <magick/defines.h>
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -194,12 +194,12 @@ static void ConcatenateImages(int argc,char **argv)
   /*
     Open output file.
   */
-  output=fopen(argv[argc-1],WriteBinaryType);
+  output=fopen(argv[argc-1],"wb");
   if (output == (FILE *) NULL)
     MagickError(FileOpenError,"Unable to open file",argv[argc-1]);
   for (i=2; i < (argc-1); i++)
   {
-    input=fopen(argv[i],ReadBinaryType);
+    input=fopen(argv[i],"rb");
     if (input == (FILE *) NULL)
       {
         MagickWarning(FileOpenWarning,"Unable to open file",argv[i]);
@@ -421,6 +421,7 @@ int main(int argc,char **argv)
   global_colormap=False;
   image=(Image *) NULL;
   GetImageInfo(&image_info);
+  option=(char *) NULL;
   scene=0;
   /*
     Parse command-line arguments.
@@ -643,6 +644,8 @@ int main(int argc,char **argv)
                     image_info.compression=BZipCompression;
                   if (Latin1Compare("Fax",option) == 0)
                     image_info.compression=FaxCompression;
+                  if (Latin1Compare("Group4",option) == 0)
+                    image_info.compression=Group4Compression;
                   if (Latin1Compare("JPEG",option) == 0)
                     image_info.compression=JPEGCompression;
                   if (Latin1Compare("LZW",option) == 0)
@@ -1173,7 +1176,7 @@ int main(int argc,char **argv)
             }
           if (strncmp("pointsize",option+1,2) == 0)
             {
-              image_info.pointsize=atoi(DefaultPointSize);
+              image_info.pointsize=12;
               if (*option == '-')
                 {
                   i++;
@@ -1272,7 +1275,7 @@ int main(int argc,char **argv)
         {
           if (strncmp("quality",option+1,2) == 0)
             {
-              image_info.quality=atoi(DefaultImageQuality);
+              image_info.quality=75;
               if (*option == '-')
                 {
                   i++;
