@@ -137,8 +137,8 @@
 /*
   Include declarations.
 */
-#include "magick.h"
-#include "defines.h"
+#include <magick/magick.h>
+#include <magick/defines.h>
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -308,7 +308,7 @@ int main(int argc,char **argv)
     *next_image;
 
   ImageInfo
-    image_info;
+    *image_info;
 
   int
     image_number,
@@ -316,7 +316,7 @@ int main(int argc,char **argv)
     x;
 
   QuantizeInfo
-    quantize_info;
+    *quantize_info;
 
   register int
     i,
@@ -351,17 +351,16 @@ int main(int argc,char **argv)
   display=(Display *) NULL;
   first_scene=0;
   image_number=0;
+  last_image=0;
   last_scene=0;
-  GetImageInfo(&image_info);
   image_marker=(unsigned int *) AllocateMemory((argc+1)*sizeof(unsigned int));
   if (image_marker == (unsigned int *) NULL)
     MagickError(ResourceLimitError,"Unable to display image",
       "Memory allocation failed");
   for (i=0; i <= argc; i++)
     image_marker[i]=argc;
-  GetQuantizeInfo(&quantize_info);
   resource_database=(XrmDatabase) NULL;
-  state=DefaultState;
+  state=0;
   /*
     Check for server name specified on the command line.
   */
@@ -398,36 +397,36 @@ int main(int argc,char **argv)
   XSetErrorHandler(XError);
   resource_database=XGetResourceDatabase(display,client_name);
   XGetResourceInfo(resource_database,client_name,&resource_info);
-  resource_info.image_info=(&image_info);
-  resource_info.quantize_info=(&quantize_info);
-  image_info.density=
+  image_info=resource_info.image_info;
+  quantize_info=resource_info.quantize_info;
+  image_info->density=
     XGetResourceInstance(resource_database,client_name,"density",(char *) NULL);
-  if (image_info.density == (char *) NULL)
-    image_info.density=XGetScreenDensity(display);
+  if (image_info->density == (char *) NULL)
+    image_info->density=XGetScreenDensity(display);
   resource_value=
     XGetResourceInstance(resource_database,client_name,"interlace","none");
-  image_info.interlace=UndefinedInterlace;
+  image_info->interlace=UndefinedInterlace;
   if (Latin1Compare("None",resource_value) == 0)
-    image_info.interlace=NoInterlace;
+    image_info->interlace=NoInterlace;
   if (Latin1Compare("Line",resource_value) == 0)
-    image_info.interlace=LineInterlace;
+    image_info->interlace=LineInterlace;
   if (Latin1Compare("Plane",resource_value) == 0)
-    image_info.interlace=PlaneInterlace;
+    image_info->interlace=PlaneInterlace;
   if (Latin1Compare("Partition",resource_value) == 0)
-    image_info.interlace=PartitionInterlace;
-  if (image_info.interlace == UndefinedInterlace)
+    image_info->interlace=PartitionInterlace;
+  if (image_info->interlace == UndefinedInterlace)
     MagickWarning(OptionWarning,"Unrecognized interlace type",resource_value);
-  image_info.page=XGetResourceInstance(resource_database,client_name,
+  image_info->page=XGetResourceInstance(resource_database,client_name,
     "pageGeometry",(char *) NULL);
   resource_value=
     XGetResourceInstance(resource_database,client_name,"quality","75");
-  image_info.quality=atoi(resource_value);
+  image_info->quality=atoi(resource_value);
   resource_value=
     XGetResourceInstance(resource_database,client_name,"verbose","False");
-  image_info.verbose=IsTrue(resource_value);
+  image_info->verbose=IsTrue(resource_value);
   resource_value=
     XGetResourceInstance(resource_database,client_name,"dither","True");
-  quantize_info.dither=IsTrue(resource_value);
+  quantize_info->dither=IsTrue(resource_value);
   /*
     Parse command line.
   */
@@ -526,55 +525,55 @@ int main(int argc,char **argv)
             }
           if (strncmp("colors",option+1,7) == 0)
             {
-              quantize_info.number_colors=0;
+              quantize_info->number_colors=0;
               if (*option == '-')
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%d",&x))
                     MagickError(OptionError,"Missing colors",option);
-                  quantize_info.number_colors=atoi(argv[i]);
+                  quantize_info->number_colors=atoi(argv[i]);
                 }
               break;
             }
           if (strncmp("colorspace",option+1,7) == 0)
             {
-              quantize_info.colorspace=RGBColorspace;
+              quantize_info->colorspace=RGBColorspace;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  quantize_info.colorspace=UndefinedColorspace;
+                  quantize_info->colorspace=UndefinedColorspace;
                   if (Latin1Compare("cmyk",option) == 0)
-                    quantize_info.colorspace=CMYKColorspace;
+                    quantize_info->colorspace=CMYKColorspace;
                   if (Latin1Compare("gray",option) == 0)
                     {
-                      quantize_info.colorspace=GRAYColorspace;
-                      quantize_info.number_colors=256;
-                      quantize_info.tree_depth=8;
+                      quantize_info->colorspace=GRAYColorspace;
+                      quantize_info->number_colors=256;
+                      quantize_info->tree_depth=8;
                     }
                   if (Latin1Compare("ohta",option) == 0)
-                    quantize_info.colorspace=OHTAColorspace;
+                    quantize_info->colorspace=OHTAColorspace;
                   if (Latin1Compare("rgb",option) == 0)
-                    quantize_info.colorspace=RGBColorspace;
+                    quantize_info->colorspace=RGBColorspace;
                   if (Latin1Compare("srgb",option) == 0)
-                    quantize_info.colorspace=sRGBColorspace;
+                    quantize_info->colorspace=sRGBColorspace;
                   if (Latin1Compare("transparent",option) == 0)
-                    quantize_info.colorspace=TransparentColorspace;
+                    quantize_info->colorspace=TransparentColorspace;
                   if (Latin1Compare("xyz",option) == 0)
-                    quantize_info.colorspace=XYZColorspace;
+                    quantize_info->colorspace=XYZColorspace;
                   if (Latin1Compare("ycbcr",option) == 0)
-                    quantize_info.colorspace=YCbCrColorspace;
+                    quantize_info->colorspace=YCbCrColorspace;
                   if (Latin1Compare("ycc",option) == 0)
-                    quantize_info.colorspace=YCCColorspace;
+                    quantize_info->colorspace=YCCColorspace;
                   if (Latin1Compare("yiq",option) == 0)
-                    quantize_info.colorspace=YIQColorspace;
+                    quantize_info->colorspace=YIQColorspace;
                   if (Latin1Compare("ypbpr",option) == 0)
-                    quantize_info.colorspace=YPbPrColorspace;
+                    quantize_info->colorspace=YPbPrColorspace;
                   if (Latin1Compare("yuv",option) == 0)
-                    quantize_info.colorspace=YUVColorspace;
-                  if (quantize_info.colorspace == UndefinedColorspace)
+                    quantize_info->colorspace=YUVColorspace;
+                  if (quantize_info->colorspace == UndefinedColorspace)
                     MagickError(OptionError,"Invalid colorspace type",option);
                 }
               break;
@@ -591,29 +590,31 @@ int main(int argc,char **argv)
             }
           if (strncmp("compress",option+1,5) == 0)
             {
-              image_info.compression=NoCompression;
+              image_info->compression=NoCompression;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  image_info.compression=UndefinedCompression;
+                  image_info->compression=UndefinedCompression;
                   if (Latin1Compare("None",option) == 0)
-                    image_info.compression=NoCompression;
+                    image_info->compression=NoCompression;
                   if (Latin1Compare("BZip",option) == 0)
-                    image_info.compression=BZipCompression;
+                    image_info->compression=BZipCompression;
                   if (Latin1Compare("Fax",option) == 0)
-                    image_info.compression=FaxCompression;
+                    image_info->compression=FaxCompression;
+                  if (Latin1Compare("Group4",option) == 0)
+                    image_info->compression=Group4Compression;
                   if (Latin1Compare("JPEG",option) == 0)
-                    image_info.compression=JPEGCompression;
+                    image_info->compression=JPEGCompression;
                   if (Latin1Compare("LZW",option) == 0)
-                    image_info.compression=LZWCompression;
+                    image_info->compression=LZWCompression;
                   if (Latin1Compare("RunlengthEncoded",option) == 0)
-                    image_info.compression=RunlengthEncodedCompression;
+                    image_info->compression=RunlengthEncodedCompression;
                   if (Latin1Compare("Zip",option) == 0)
-                    image_info.compression=ZipCompression;
-                  if (image_info.compression == UndefinedCompression)
+                    image_info->compression=ZipCompression;
+                  if (image_info->compression == UndefinedCompression)
                     MagickError(OptionError,"Invalid compression type",option);
                 }
               break;
@@ -654,13 +655,13 @@ int main(int argc,char **argv)
             }
           if (strncmp("density",option+1,3) == 0)
             {
-              image_info.density=(char *) NULL;
+              image_info->density=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  (void) CloneString(&image_info.density,argv[i]);
+                  (void) CloneString(&image_info->density,argv[i]);
                 }
               break;
             }
@@ -668,31 +669,31 @@ int main(int argc,char **argv)
             break;
           if (Latin1Compare("display",option+1) == 0)
             {
-              image_info.server_name=(char *) NULL;
+              image_info->server_name=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing server name",option);
-                  image_info.server_name=argv[i];
+                  image_info->server_name=argv[i];
                 }
               break;
             }
           if (strncmp("dispose",option+1,5) == 0)
             {
-              image_info.dispose=(char *) NULL;
+              image_info->dispose=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%d",&x))
                     MagickError(OptionError,"Missing method",option);
-                  image_info.dispose=PostscriptGeometry(argv[i]);
+                  image_info->dispose=PostscriptGeometry(argv[i]);
                 }
               break;
             }
           if (strncmp("dither",option+1,3) == 0)
             {
-              quantize_info.dither=(*option == '-');
+              quantize_info->dither=(*option == '-');
               break;
             }
           MagickError(OptionError,"Unrecognized option",option);
@@ -719,45 +720,45 @@ int main(int argc,char **argv)
         {
           if (strncmp("filter",option+1,3) == 0)
             {
-              image_info.filter=MitchellFilter;
+              image_info->filter=MitchellFilter;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  image_info.filter=UndefinedFilter;
+                  image_info->filter=UndefinedFilter;
                   if (Latin1Compare("Point",option) == 0)
-                    image_info.filter=PointFilter;
+                    image_info->filter=PointFilter;
                   if (Latin1Compare("Box",option) == 0)
-                    image_info.filter=BoxFilter;
+                    image_info->filter=BoxFilter;
                   if (Latin1Compare("Triangle",option) == 0)
-                    image_info.filter=TriangleFilter;
+                    image_info->filter=TriangleFilter;
                   if (Latin1Compare("Hermite",option) == 0)
-                    image_info.filter=HermiteFilter;
+                    image_info->filter=HermiteFilter;
                   if (Latin1Compare("Hanning",option) == 0)
-                    image_info.filter=HanningFilter;
+                    image_info->filter=HanningFilter;
                   if (Latin1Compare("Hamming",option) == 0)
-                    image_info.filter=HammingFilter;
+                    image_info->filter=HammingFilter;
                   if (Latin1Compare("Blackman",option) == 0)
-                    image_info.filter=BlackmanFilter;
+                    image_info->filter=BlackmanFilter;
                   if (Latin1Compare("Gaussian",option) == 0)
-                    image_info.filter=GaussianFilter;
+                    image_info->filter=GaussianFilter;
                   if (Latin1Compare("Quadratic",option) == 0)
-                    image_info.filter=QuadraticFilter;
+                    image_info->filter=QuadraticFilter;
                   if (Latin1Compare("Cubic",option) == 0)
-                    image_info.filter=CubicFilter;
+                    image_info->filter=CubicFilter;
                   if (Latin1Compare("Catrom",option) == 0)
-                    image_info.filter=CatromFilter;
+                    image_info->filter=CatromFilter;
                   if (Latin1Compare("Mitchell",option) == 0)
-                    image_info.filter=MitchellFilter;
+                    image_info->filter=MitchellFilter;
                   if (Latin1Compare("Lanczos",option) == 0)
-                    image_info.filter=LanczosFilter;
+                    image_info->filter=LanczosFilter;
                   if (Latin1Compare("Bessel",option) == 0)
-                    image_info.filter=BesselFilter;
+                    image_info->filter=BesselFilter;
                   if (Latin1Compare("Sinc",option) == 0)
-                    image_info.filter=SincFilter;
-                  if (image_info.filter == UndefinedFilter)
+                    image_info->filter=SincFilter;
+                  if (image_info->filter == UndefinedFilter)
                     MagickError(OptionError,"Invalid filter type",option);
                 }
               break;
@@ -768,17 +769,17 @@ int main(int argc,char **argv)
             break;
           if (strncmp("font",option+1,3) == 0)
             {
-              image_info.font=(char *) NULL;
+              image_info->font=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing font name",option);
-                  image_info.font=argv[i];
+                  image_info->font=argv[i];
                 }
-              if ((image_info.font == (char *) NULL) ||
-                  (*image_info.font != '@'))
-                resource_info.font=image_info.font;
+              if ((image_info->font == (char *) NULL) ||
+                  (*image_info->font != '@'))
+                resource_info.font=image_info->font;
               break;
             }
           if ((strncmp("foreground",option+1,3) == 0) ||
@@ -864,23 +865,23 @@ int main(int argc,char **argv)
             }
           if (strncmp("interlace",option+1,3) == 0)
             {
-              image_info.interlace=NoInterlace;
+              image_info->interlace=NoInterlace;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  image_info.interlace=UndefinedInterlace;
+                  image_info->interlace=UndefinedInterlace;
                   if (Latin1Compare("None",option) == 0)
-                    image_info.interlace=NoInterlace;
+                    image_info->interlace=NoInterlace;
                   if (Latin1Compare("Line",option) == 0)
-                    image_info.interlace=LineInterlace;
+                    image_info->interlace=LineInterlace;
                   if (Latin1Compare("Plane",option) == 0)
-                    image_info.interlace=PlaneInterlace;
+                    image_info->interlace=PlaneInterlace;
                   if (Latin1Compare("Partition",option) == 0)
-                    image_info.interlace=PartitionInterlace;
-                  if (image_info.interlace == UndefinedInterlace)
+                    image_info->interlace=PartitionInterlace;
+                  if (image_info->interlace == UndefinedInterlace)
                     MagickError(OptionError,"Invalid interlace type",option);
                 }
               break;
@@ -947,12 +948,12 @@ int main(int argc,char **argv)
             }
           if (strncmp("monochrome",option+1,3) == 0)
             {
-              image_info.monochrome=(*option == '-');
-              if (image_info.monochrome)
+              image_info->monochrome=(*option == '-');
+              if (image_info->monochrome)
                 {
-                  quantize_info.number_colors=2;
-                  quantize_info.tree_depth=8;
-                  quantize_info.colorspace=GRAYColorspace;
+                  quantize_info->number_colors=2;
+                  quantize_info->tree_depth=8;
+                  quantize_info->colorspace=GRAYColorspace;
                 }
               break;
             }
@@ -982,13 +983,13 @@ int main(int argc,char **argv)
         {
           if (strncmp("page",option+1,3) == 0)
             {
-              image_info.page=(char *) NULL;
+              image_info->page=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing page geometry",option);
-                  image_info.page=PostscriptGeometry(argv[i]);
+                  image_info->page=PostscriptGeometry(argv[i]);
                 }
               break;
             }
@@ -999,13 +1000,13 @@ int main(int argc,char **argv)
         {
           if (strncmp("quality",option+1,2) == 0)
             {
-              image_info.quality=atoi(DefaultImageQuality);
+              image_info->quality=75;
               if (*option == '-')
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%d",&x))
                     MagickError(OptionError,"Missing quality",option);
-                  image_info.quality=atoi(argv[i]);
+                  image_info->quality=atoi(argv[i]);
                 }
               break;
             }
@@ -1106,13 +1107,13 @@ int main(int argc,char **argv)
             }
           if (strncmp("size",option+1,2) == 0)
             {
-              image_info.size=(char *) NULL;
+              image_info->size=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  image_info.size=argv[i];
+                  image_info->size=argv[i];
                 }
               break;
             }
@@ -1135,13 +1136,13 @@ int main(int argc,char **argv)
             }
           if (strncmp("texture",option+1,5) == 0)
             {
-              image_info.texture=(char *) NULL;
+              image_info->texture=(char *) NULL;
               if (*option == '-')
                 {
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing filename",option);
-                  image_info.texture=argv[i];
+                  image_info->texture=argv[i];
                 }
               break;
             }
@@ -1159,13 +1160,13 @@ int main(int argc,char **argv)
             }
           if (strncmp("treedepth",option+1,3) == 0)
             {
-              quantize_info.tree_depth=0;
+              quantize_info->tree_depth=0;
               if (*option == '-')
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%d",&x))
                     MagickError(OptionError,"Missing depth",option);
-                  quantize_info.tree_depth=atoi(argv[i]);
+                  quantize_info->tree_depth=atoi(argv[i]);
                 }
               break;
             }
@@ -1198,7 +1199,7 @@ int main(int argc,char **argv)
         {
           if (strncmp("verbose",option+1,2) == 0)
             {
-              image_info.verbose=(*option == '-');
+              image_info->verbose=(*option == '-');
               break;
             }
           if (strncmp("visual",option+1,3) == 0)
@@ -1291,7 +1292,7 @@ int main(int argc,char **argv)
           /*
             Read image.
           */
-          (void) strcpy(image_info.filename,option);
+          (void) strcpy(image_info->filename,option);
           if (first_scene != last_scene)
             {
               char
@@ -1300,15 +1301,15 @@ int main(int argc,char **argv)
               /*
                 Form filename for multi-part images.
               */
-              FormatString(filename,image_info.filename,scene);
-              if (Latin1Compare(filename,image_info.filename) == 0)
-                FormatString(filename,"%.1024s.%u",image_info.filename,scene);
-              (void) strcpy(image_info.filename,filename);
+              FormatString(filename,image_info->filename,scene);
+              if (Latin1Compare(filename,image_info->filename) == 0)
+                FormatString(filename,"%.1024s.%u",image_info->filename,scene);
+              (void) strcpy(image_info->filename,filename);
             }
-          (void) strcpy(image_info.magick,"MIFF");
-          image_info.colorspace=quantize_info.colorspace;
-          image_info.dither=quantize_info.dither;
-          image=ReadImage(&image_info);
+          (void) strcpy(image_info->magick,"MIFF");
+          image_info->colorspace=quantize_info->colorspace;
+          image_info->dither=quantize_info->dither;
+          image=ReadImage(image_info);
           if (image == (Image *) NULL)
             {
               if ((i < (argc-1)) || (scene < last_scene))
@@ -1325,7 +1326,7 @@ int main(int argc,char **argv)
               Transmogrify image as defined by the image processing options.
             */
             resource_info.quantum=1;
-            MogrifyImage(&image_info,i,argv,&image);
+            MogrifyImage(image_info,i,argv,&image);
             if (first_scene != last_scene)
               image->scene=scene;
             /*
@@ -1367,7 +1368,7 @@ int main(int argc,char **argv)
                       image=loaded_image;
                       break;
                     }
-                  MogrifyImage(&image_info,i,argv,&loaded_image);
+                  MogrifyImage(image_info,i,argv,&loaded_image);
                   if (first_scene != last_scene)
                     image->scene=scene;
                   next_image=XDisplayImage(display,&resource_info,argv,argc,
@@ -1393,9 +1394,9 @@ int main(int argc,char **argv)
                   Write image.
                 */
                 (void) strcpy(image->filename,resource_info.write_filename);
-                (void) WriteImage(&image_info,image);
+                (void) WriteImage(image_info,image);
               }
-            if (image_info.verbose)
+            if (image_info->verbose)
               DescribeImage(image,stdout,False);
             /*
               Proceed to next/previous image.
