@@ -165,6 +165,7 @@ static Image *XMagickCommand(Display *display,XResourceInfo *resource_info,
       if (local_info == (ImageInfo *) NULL)
         break;
       image=(Image *) NULL;
+      handler=(MonitorHandler) NULL;
       XSetCursorState(display,windows,True);
       XCheckRefreshWindows(display,windows);
       for (i=0; i < number_files; i++)
@@ -286,7 +287,7 @@ static Image *XMagickCommand(Display *display,XResourceInfo *resource_info,
         User requested help.
       */
       XTextViewWidget(display,resource_info,windows,False,
-        "Help Viewer - Animate",ImageMagickHelp);
+        "Help Viewer - Animate",AnimateHelp);
       break;
     }
     case BrowseDocumentationCommand:
@@ -313,7 +314,7 @@ static Image *XMagickCommand(Display *display,XResourceInfo *resource_info,
             Display documentation using Netscape remote control.
           */
           FormatString(command,"openURL(%.1024s,new-window,noraise)",
-            DocumentationURL);
+            "http://www.wizards.dupont.com/cristy/ImageMagick.html");
           mozilla_atom=XInternAtom(display,"_MOZILLA_COMMAND",False);
           XChangeProperty(display,mozilla_window,mozilla_atom,XA_STRING,8,
             PropModeReplace,(unsigned char *) command,Extent(command));
@@ -2283,7 +2284,6 @@ windows->image.pixel_info=(&scene_info);
   XCheckRefreshWindows(display,windows);
   for (scene=1; scene < (int) number_scenes; scene++)
   {
-    DestroyImage(images[scene]);
     if (windows->image.pixmaps[scene] != (Pixmap) NULL)
       XFreePixmap(display,windows->image.pixmaps[scene]);
     windows->image.pixmaps[scene]=(Pixmap) NULL;
