@@ -11,15 +11,12 @@ extern "C" {
 /*
   Define declarations.
 */
-#define DefaultPageSize  "Letter"
 #define MaxColors  Min(windows->visual_info->colormap_size,256)
-#define MinPanSize  96
-#define RoiDelta  8
 
 /*
   Static declarations.
 */
-static const char
+const char
   *NoiseTypes[] =
   {
     "Uniform",
@@ -85,7 +82,7 @@ static const char
 /*
   Help widget declarations.
 */
-static const char
+const char
   *ImageAnnotateHelp[]=
   {
     "In annotate mode, the Command widget has these options:",
@@ -243,6 +240,13 @@ static const char
     "      yellow",
     "      white",
     "      Browser...",
+    "    Fuzz",
+    "      0",
+    "      2",
+    "      4",
+    "      8",
+    "      16",
+    "      Dialog...",
     "    Undo",
     "    Help",
     "    Dismiss",
@@ -595,7 +599,7 @@ static const char
     "starting point of the line and release the button.",
     (char *) NULL,
   },
-  *ImageMagickHelp[]=
+  *DisplayHelp[]=
   {
     "BUTTONS",
     "  The effects of each button press is described below.  Three",
@@ -951,6 +955,13 @@ static const char
     "      yellow",
     "      white",
     "      Browser...",
+    "    Fuzz",
+    "      0",
+    "      2",
+    "      4",
+    "      8",
+    "      16",
+    "      Dialog...",
     "    Matte",
     "    Undo",
     "    Help",
@@ -1377,6 +1388,7 @@ typedef enum
   ColorEditMethodCommand,
   ColorEditColorCommand,
   ColorEditBorderCommand,
+  ColorEditFuzzCommand,
   ColorEditUndoCommand,
   ColorEditHelpCommand,
   ColorEditDismissCommand,
@@ -1399,6 +1411,7 @@ typedef enum
   DrawDismissCommand,
   MatteEditMethod,
   MatteEditBorderCommand,
+  MatteEditFuzzCommand,
   MatteEditValueCommand,
   MatteEditUndoCommand,
   MatteEditHelpCommand,
@@ -1439,7 +1452,7 @@ typedef enum
 #define WavyWidth  16
 #define WavyHeight  16
 
-static const unsigned char
+const unsigned char
   BricksBitmap[] =
   {
     0xff, 0xff, 0x0f, 0x03, 0x0c, 0x00, 0x03, 0x0c, 0x00, 0x03, 0x0c, 0x00,
@@ -1454,20 +1467,12 @@ static const unsigned char
     0x11, 0x11, 0x22, 0x22, 0x44, 0x44, 0x88, 0x88, 0x11, 0x11, 0x22, 0x22,
     0x44, 0x44, 0x88, 0x88, 0x11, 0x11, 0x22, 0x22
   },
-  HighlightBitmap[] =
-  {
-    0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55
-  },
   ScalesBitmap[] =
   {
     0x08, 0x08, 0x08, 0x08, 0x14, 0x14, 0xe3, 0xe3, 0x80, 0x80, 0x80, 0x80,
     0x41, 0x41, 0x3e, 0x3e, 0x08, 0x08, 0x08, 0x08, 0x14, 0x14, 0xe3, 0xe3,
     0x80, 0x80, 0x80, 0x80, 0x41, 0x41, 0x3e, 0x3e
   },
-  ShadowBitmap[] =
-  {
-    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
-  },
   VerticalBitmap[] =
   {
     0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11,
