@@ -38,14 +38,6 @@ typedef unsigned short Quantum;
 typedef unsigned char Quantum;
 #endif
 
-/*
-  Image Geometry defines (extends XParseGeometry flags).
-*/
-#define PercentValue  0x1000
-#define AspectValue  0x2000
-#define LessValue  0x4000
-#define GreaterValue  0x8000
-
 /*
   Typedef declarations.
 */
@@ -263,23 +255,14 @@ typedef struct _SegmentInfo
     y2;
 } SegmentInfo;
 
-typedef struct _AnnotateInfo
+typedef struct _ProfileInfo
 {
-  ImageInfo
-    *image_info;
-
   unsigned int
-    gravity;
+    length;
 
-  char
-    *geometry,
-    *text,
-    *primitive,
-    *font_name;
-
-  RectangleInfo
-    bounds;
-} AnnotateInfo;
+  unsigned char
+    *info;
+} ProfileInfo;
 
 typedef struct _ChromaticityInfo
 {
@@ -290,15 +273,6 @@ typedef struct _ChromaticityInfo
     white_point;
 } ChromaticityInfo;
 
-typedef struct _ProfileInfo
-{
-  unsigned int
-    length;
-
-  unsigned char
-    *info;
-} ProfileInfo;
-
 typedef struct _Image
 {
   FILE
@@ -457,6 +431,46 @@ typedef struct _Image
     *list,
     *next;
 } Image;
+
+typedef struct _AnnotateInfo
+{
+  ImageInfo
+    *image_info;
+
+  unsigned int
+    gravity;
+
+  char
+    *geometry,
+    *text,
+    *primitive,
+    *font_name;
+
+  Image
+    *tile;
+
+  RectangleInfo
+    bounds;
+} AnnotateInfo;
+
+/*
+  Image const declarations.
+*/
+extern const char
+  *Alphabet,
+  *DefaultPointSize,
+  *DefaultImageQuality,
+  *DefaultTileFrame,
+  *DefaultTileGeometry,
+  *DefaultTileLabel,
+  *PSDensityGeometry,
+  *PSPageGeometry,
+  *ReadBinaryType,
+  *ReadBinaryUnbufferedType,
+  *WriteBinaryType;
+
+extern const double
+  SharpenFactor;
 
 /*
   Image utilities methods.
@@ -579,6 +593,8 @@ extern Export int
   ParseImageGeometry(const char *,int *,int *,unsigned int *,unsigned int *);
 
 extern Export unsigned int
+  AnimateImages(const ImageInfo *image_info,Image *image),
+  DisplayImages(const ImageInfo *image_info,Image *image),
   GetNumberScenes(const Image *),
   IsGeometry(const char *),
   IsGrayImage(Image *),
@@ -603,7 +619,7 @@ extern Export unsigned int
   WriteHTMLImage(const ImageInfo *image_info,Image *image),
   WriteICCImage(const ImageInfo *image_info,Image *image),
   WriteIPTCImage(const ImageInfo *image_info,Image *image),
-  WriteImage(ImageInfo *,Image *),
+  WriteImage(const ImageInfo *,Image *),
   WriteJBIGImage(const ImageInfo *image_info,Image *image),
   WriteJPEGImage(const ImageInfo *image_info,Image *image),
   WriteLOGOImage(const ImageInfo *image_info,Image *image),
@@ -645,7 +661,7 @@ extern Export void
   AnnotateImage(Image *,const AnnotateInfo *),
   CloseImage(Image *),
   CoalesceImages(Image *),
-  ColorFloodfillImage(Image *,const RunlengthPacket *,const char *,const int x,
+  ColorFloodfillImage(Image *,const RunlengthPacket *,Image *,const int x,
     const int y,const PaintMethod),
   ColorizeImage(Image *,const char *,const char *),
   CommentImage(Image *,const char *),
