@@ -53,7 +53,6 @@
 */
 #include "magick.h"
 #include "defines.h"
-#include "Colorlist.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -244,7 +243,7 @@ Export char *BaseFilename(const char *name)
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method IsAccessible returns True is the string is cloned,
+%    o status:  Method CloneString returns True is the string is cloned,
 %      otherwise False is returned.
 %
 %    o destination:  A pointer to a character string.
@@ -785,11 +784,6 @@ Export int GetGeometry(const char *image_geometry,int *x,int *y,
     Parse geometry using XParseGeometry.
   */
   flags|=XParseGeometry(geometry,x,y,width,height);
-  if (((flags & WidthValue) != 0) && (flags & HeightValue) == 0)
-    {
-      *height=(*width);
-      flags|=HeightValue;
-    }
   return(flags);
 }
 
@@ -1233,7 +1227,7 @@ Export void Latin1Upper(char *string)
     if (isupper(c))
       continue;
     c=toupper(c);
-    *string=c;
+    *string=(char) c;
   }
 }
 
@@ -2082,44 +2076,71 @@ Export char *PostscriptGeometry(const char *page)
   static const char
     *PageSizes[][2]=
     {
-      { "11x17", "792x1224>" },
-      { "LEDGER", "1224x792>" },
-      { "LEGAL", "612x1008>" },
-      { "LETTER", "612x792>" },
-      { "LETTERSMALL", "612x792>" },
-      { "ARCHE", "2592x3456>" },
-      { "ARCHD", "1728x2592>" },
-      { "ARCHC", "1296x1728>" },
-      { "ARCHB", "864x1296>" },
-      { "ARCHA", "648x864>" },
-      { "A0", "2380x3368>" },
-      { "A1", "1684x2380>" },
-      { "A2", "1190x1684>" },
-      { "A3", "842x1190>" },
-      { "A4", "595x842>" },
+      { "10x13",  "720x936>" },
+      { "10x14",  "720x1008>" },
+      { "11x17",  "792x1224>" },
+      { "7x9",  "504x648>" },
+      { "9x11",  "648x792>" },
+      { "9x12",  "648x864>" },
+      { "A0",  "2384x3370>" },
+      { "A1",  "1684x2384>" },
+      { "A10", "73x105>" },
+      { "A2",  "1191x1684>" },
+      { "A3",  "842x1191>" },
+      { "A4",  "595x842>" },
       { "A4SMALL", "595x842>" },
-      { "A5", "421x595>" },
-      { "A6", "297x421>" },
-      { "A7", "210x297>" },
-      { "A8", "148x210>" },
-      { "A9", "105x148>" },
-      { "A10", "74x105>" },
-      { "B0", "2836x4008>" },
-      { "B1", "2004x2836>" },
-      { "B2", "1418x2004>" },
-      { "B3", "1002x1418>" },
-      { "B4", "709x1002>" },
-      { "B5", "501x709>" },
-      { "C0", "2600x3677>" },
-      { "C1", "1837x2600>" },
-      { "C2", "1298x1837>" },
-      { "C3", "918x1298>" },
-      { "C4", "649x918>" },
-      { "C5", "459x649>" },
-      { "C6", "323x459>" },
+      { "A5",  "420x595>" },
+      { "A6",  "297x420>" },
+      { "A7",  "210x297>" },
+      { "A8",  "148x210>" },
+      { "A9",  "105x148>" },
+      { "ARCHA", "648x864>" },
+      { "ARCHB", "864x1296>" },
+      { "ARCHC", "1296x1728>" },
+      { "ARCHD", "1728x2592>" },
+      { "ARCHE", "2592x3456>" },
+      { "B0",  "2920x4127>" },
+      { "B1",  "2064x2920>" },
+      { "B10", "91x127>" },
+      { "B2",  "1460x2064>" },
+      { "B3",  "1032x1460>" },
+      { "B4",  "729x1032>" },
+      { "B5",  "516x729>" },
+      { "B6",  "363x516>" },
+      { "B7",  "258x363>" },
+      { "B8",  "181x258>" },
+      { "B9",  "127x181>" },
+      { "C0",  "2599x3676>" },
+      { "C1",  "1837x2599>" },
+      { "C2",  "1298x1837>" },
+      { "C3",  "918x1296>" },
+      { "C4",  "649x918>" },
+      { "C5",  "459x649>" },
+      { "C6",  "323x459>" },
+      { "C7",  "230x323>" },
+      { "EXECUTIVE", "540x720>" },
       { "FLSA", "612x936>" },
       { "FLSE", "612x936>" },
+      { "FOLIO",  "612x936>" },
       { "HALFLETTER", "396x612>" },
+      { "ISOB0", "2835x4008>" },
+      { "ISOB1", "2004x2835>" },
+      { "ISOB10", "88x125>" },
+      { "ISOB2", "1417x2004>" },
+      { "ISOB3", "1001x1417>" },
+      { "ISOB4", "709x1001>" },
+      { "ISOB5", "499x709>" },
+      { "ISOB6", "354x499>" },
+      { "ISOB7", "249x354>" },
+      { "ISOB8", "176x249>" },
+      { "ISOB9", "125x176>" },
+      { "LEDGER",  "1224x792>" },
+      { "LEGAL",  "612x1008>" },
+      { "LETTER", "612x792>" },
+      { "LETTERSMALL",  "612x792>" },
+      { "QUARTO",  "610x780>" },
+      { "STATEMENT",  "396x612>" },
+      { "TABLOID",  "792x1224>" },
       { (char *) NULL, (char *) NULL }
     };
 
