@@ -1,3 +1,13 @@
+/*
+  ImageMagick Utility Methods.
+*/
+#ifndef _UTILITY_H
+#define _UTILITY_H
+
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #if !defined(vms) && !defined(macintosh) && !defined(WIN32)
 #if HAVE_SYS_NDIR_H || HAVE_SYS_DIR_H || HAVE_NDIR_H
 # define dirent direct
@@ -32,43 +42,6 @@
 #define S_ISDIR(mode) (((mode) & S_IFMT) == S_IFDIR)
 #endif
 
-/*
-  Utility define declarations.
-*/
-#if !defined(vms)
-#define IsGlob(text) \
-  ((strchr(text,'*') != (char *) NULL) || \
-   (strchr(text,'?') != (char *) NULL) || \
-   (strchr(text,'{') != (char *) NULL) || \
-   (strchr(text,'}') != (char *) NULL) || \
-   (strchr(text,'[') != (char *) NULL) || \
-   (strchr(text,']') != (char *) NULL))
-#else
-#define IsGlob(text) \
-  ((strchr(text,'*') != (char *) NULL) || \
-   (strchr(text,'?') != (char *) NULL) || \
-   (strchr(text,'{') != (char *) NULL) || \
-   (strchr(text,'}') != (char *) NULL))
-#endif
-#if !defined(vms) && !defined(macintosh) && !defined(WIN32)
-#define IsBasenameSeparator(c)  ((c) == '/')
-#define DirectorySeparator  "/"
-#define TemporaryTemplate  "magick"
-#else
-#if defined(vms)
-#define IsBasenameSeparator(c)  ((c) == ']')
-#define DirectorySeparator  ""
-#endif
-#if defined(macintosh)
-#define IsBasenameSeparator(c)  ((c) == ':')
-#define DirectorySeparator  ":"
-#endif
-#if defined(WIN32)
-#define IsBasenameSeparator(c)  (((c) == '/') || ((c) == '\\'))
-#define DirectorySeparator  "\\"
-#endif
-#endif
-
 /*
   Utilities methods.
 */
@@ -85,13 +58,14 @@ extern Export char
 
 extern Export int
   GetGeometry(const char *,int *,int *,unsigned int *,unsigned int *),
-  GlobExpression(char *,const char *),
+  GlobExpression(const char *,const char *),
   Latin1Compare(const char *,const char *),
   MultilineCensus(const char *),
   ReadDataBlock(char *,FILE *),
-  SystemCommand(unsigned int,char *);
+  SystemCommand(const unsigned int,const char *);
 
 extern Export unsigned int
+  CloneString(char **,const char *),
   ExpandFilenames(int *,char ***),
   IsAccessible(const char *),
   IsDirectory(const char *),
@@ -108,7 +82,6 @@ extern Export unsigned short
 
 extern Export void
   AppendImageFormat(const char *,char *),
-  CloneString(char **,const char *),
   DestroyPostscriptGeometry(char *),
   ExpandFilename(char *),
   FormatString(char *,const char *,...),
@@ -122,3 +95,9 @@ extern Export void
   MSBFirstWriteShort(const unsigned int,FILE *),
   Strip(char *),
   TemporaryFilename(char *);
+
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
+#endif
