@@ -143,8 +143,8 @@
 /*
   Include declarations.
 */
-#include "magick.h"
-#include "defines.h"
+#include <magick/magick.h>
+#include <magick/defines.h>
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -338,6 +338,7 @@ int main(int argc,char **argv)
   image=(Image *) NULL;
   GetImageInfo(&image_info);
   scene=0;
+  status=False;
   /*
     Parse command line.
   */
@@ -514,6 +515,8 @@ int main(int argc,char **argv)
                     image_info.compression=BZipCompression;
                   if (Latin1Compare("Fax",option) == 0)
                     image_info.compression=FaxCompression;
+                  if (Latin1Compare("Group4",option) == 0)
+                    image_info.compression=Group4Compression;
                   if (Latin1Compare("JPEG",option) == 0)
                     image_info.compression=JPEGCompression;
                   if (Latin1Compare("LZW",option) == 0)
@@ -1051,7 +1054,7 @@ int main(int argc,char **argv)
             }
           if (strncmp("pointsize",option+1,2) == 0)
             {
-              image_info.pointsize=atoi(DefaultPointSize);
+              image_info.pointsize=12;
               if (*option == '-')
                 {
                   i++;
@@ -1068,7 +1071,7 @@ int main(int argc,char **argv)
         {
           if (strncmp("quality",option+1,2) == 0)
             {
-              image_info.quality=atoi(DefaultImageQuality);
+              image_info.quality=75;
               if (*option == '-')
                 {
                   i++;
