@@ -139,8 +139,8 @@
 /*
   Include declarations.
 */
-#include "magick.h"
-#include "defines.h"
+#include <magick/magick.h>
+#include <magick/defines.h>
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -452,6 +452,8 @@ int main(int argc,char **argv)
                     image_info.compression=BZipCompression;
                   if (Latin1Compare("Fax",option) == 0)
                     image_info.compression=FaxCompression;
+                  if (Latin1Compare("Group4",option) == 0)
+                    image_info.compression=Group4Compression;
                   if (Latin1Compare("JPEG",option) == 0)
                     image_info.compression=JPEGCompression;
                   if (Latin1Compare("LZW",option) == 0)
@@ -804,7 +806,7 @@ int main(int argc,char **argv)
                   if (Latin1Compare("frame",option) == 0)
                     {
                       mode=FrameMode;
-                      (void) CloneString(&montage_info.frame,DefaultTileFrame);
+                      (void) CloneString(&montage_info.frame,"15x15+3+3");
                       montage_info.shadow=True;
                       break;
                     }
@@ -874,8 +876,8 @@ int main(int argc,char **argv)
             }
           if (strncmp("pointsize",option+1,2) == 0)
             {
-              image_info.pointsize=atoi(DefaultPointSize);
-              montage_info.pointsize=atoi(DefaultPointSize);
+              image_info.pointsize=12;
+              montage_info.pointsize=12;
               if (*option == '-')
                 {
                   i++;
@@ -893,7 +895,7 @@ int main(int argc,char **argv)
         {
           if (strncmp("quality",option+1,2) == 0)
             {
-              image_info.quality=atoi(DefaultImageQuality);
+              image_info.quality=75;
               if (*option == '-')
                 {
                   i++;
